@@ -83,6 +83,10 @@ class CalendarPlugin(hildondesktop.HomeItem):
     self._prefSave('title_alpha',str(self._widgetTree.get_widget("color_title").get_current_alpha()))
     self._prefSave('font',self._widgetTree.get_widget("fontselection").get_font_name())
     self._prefSave('autosize',str(int(self._widgetTree.get_widget("bautosize").get_active())))
+    self._prefSave('today',str(int(self._widgetTree.get_widget("btoday").get_active())))
+    self._prefSave('tomorrow',str(int(self._widgetTree.get_widget("btomorrow").get_active())))
+    self._prefSave('after_tomorrow',str(int(self._widgetTree.get_widget("bafter_tomorrow").get_active())))
+    self._prefSave('week',str(int(self._widgetTree.get_widget("week").get_active())))
     self._window.destroy()
 
   def _cancel(self,widget,*data):
@@ -92,7 +96,7 @@ class CalendarPlugin(hildondesktop.HomeItem):
     self._window.destroy()
 
   def _prefRead(self,key):
-    default = {'background':'#000000','background_alpha':'32767','foreground':'#FFFFFF','foreground_alpha':'65535','title':'#FFAB00','title_alpha':'65535','font':'Sans 16','autosize':'1'}
+    default = {'background':'#000000','background_alpha':'32767','foreground':'#FFFFFF','foreground_alpha':'65535','title':'#FFAB00','title_alpha':'65535','font':'Sans 16','autosize':'1','today':'1','tomorrow':'1','after_tomorrow':'0','week':'0'}
     c = ConfigParser(default)
     c.read('/home/user/.homecalendar')
 #   print key+':'+str(c.get("DEFAULT", key))
@@ -100,7 +104,7 @@ class CalendarPlugin(hildondesktop.HomeItem):
 
   def _prefSave(self,key,value):
 #   print str(key) + ':' + str(value)
-    default = {'background':'#000000','background_alpha':'32767','foreground':'#FFFFFF','foreground_alpha':'65535','title':'#FFAB00','title_alpha':'65535','font':'Sans 16','autosize':'1'}
+    default = {'background':'#000000','background_alpha':'32767','foreground':'#FFFFFF','foreground_alpha':'65535','title':'#FFAB00','title_alpha':'65535','font':'Sans 16','autosize':'1','today':'1','tomorrow':'1','after_tomorrow':'0','week':'0'}
     c = ConfigParser(default)
     c.read('/home/user/.homecalendar')
     c.set('DEFAULT',key,value)
@@ -123,6 +127,10 @@ class CalendarPlugin(hildondesktop.HomeItem):
     self._widgetTree.get_widget("color_title").set_has_opacity_control(True)
     self._widgetTree.get_widget("fontselection").set_font_name(self._prefRead('font'))
     self._widgetTree.get_widget("bautosize").set_active(int(self._prefRead('autosize')))
+    self._widgetTree.get_widget("btoday").set_active(int(self._prefRead('today')))
+    self._widgetTree.get_widget("btomorrow").set_active(int(self._prefRead('tomorrow')))
+    self._widgetTree.get_widget("bafter_tomorrow").set_active(int(self._prefRead('after_tomorrow')))
+    self._widgetTree.get_widget("bweek").set_active(int(self._prefRead('week')))
 
     callbackMapping = {
       # Signal
@@ -236,7 +244,7 @@ class CalendarPlugin(hildondesktop.HomeItem):
       text = '\n - Nothing'
     for (event_date,event_uuid) in event_uuid_list:
       event = mcalendar_framework.Event(event_uuid)
-      text = text + '\n '+event.start_datetime.strftime('%x')+'-'+event.end_datetime.strftime('%x')+' : ' + event.title
+      text = text + '\n '+event.start_datetime.strftime('%X')+'-'+event.end_datetime.strftime('%X')+' : ' + event.title
     return text
 
   def get_tomorrow(self):
@@ -248,7 +256,40 @@ class CalendarPlugin(hildondesktop.HomeItem):
       text = '\n - Nothing'
     for (event_date,event_uuid) in event_uuid_list:
       event = mcalendar_framework.Event(event_uuid)
-      text = text + '\n '+event.start_datetime.strftime('%x')+'-'+event.end_datetime.strftime('%x')+' : ' + event.title
+      text = text + '\n '+event.start_datetime.strftime('%X')+'-'+event.end_datetime.strftime('%X')+' : ' + event.title
+    return text
+
+  def _get_week_details(self,date):
+    nb_day = date.weekday()
+    diff = datetime.timedelta(days=nb_day)
+    first_day = date - diff
+    nb_day = 6 - date.weekday()
+    diff = datetime.timedelta(days=nb_day)
+    last_day = date + diff
+    return (first_day,last_day)
+    
+  def get_week(self):
+    week_start,week_end = self._get_week_details(datetime.datetime.now())
+    event_uuid_list =  mcalendar_framework.EventList().get_events_for_date_interval(week_start,week_end)
+    event_uuid_list.sort()    
+    text = ""
+    if len(event_uuid_list)==0:
+      text = '\n - Nothing'
+    for (event_date,event_uuid) in event_uuid_list:
+      event = mcalendar_framework.Event(event_uuid)
+      text = text + '\n '+event.start_datetime.strftime('%x-%X')+'-'+event.end_datetime.strftime('%X')+' : ' + event.title
+    return text
+    
+  def get_after_tomorrow(self):
+    diff = datetime.timedelta(days=2)
+    event_uuid_list =  mcalendar_framework.EventList().get_events_for_one_day(datetime.datetime.now()+diff)
+    event_uuid_list.sort()    
+    text = ""
+    if len(event_uuid_list)==0:
+      text = '\n - Nothing'
+    for (event_date,event_uuid) in event_uuid_list:
+      event = mcalendar_framework.Event(event_uuid)
+      text = text + '\n '+event.start_datetime.strftime('%X')+'-'+event.end_datetime.strftime('%X')+' : ' + event.title
     return text
 
   def get_text(self):
@@ -256,6 +297,7 @@ class CalendarPlugin(hildondesktop.HomeItem):
     tomorrow = '<span foreground="'+self._prefRead('title')+'">Tomorrow</span>'+self.get_tomorrow()
     text = today + '\n\n'+tomorrow 
     return text
+    
 def hd_plugin_get_objects():
   plugin = CalendarPlugin()
   return [plugin]
